" ==============================================================================
" PLUGINS
" This
filetype off

"" automatically install new plugs
if empty(glob('~/.vim/autoload/plug.vim'))
  silent !curl -fLo ~/.vim/autoload/plug.vim --create-dirs
    \ https://raw.githubusercontent.com/junegunn/vim-plug/master/plug.vim
  autocmd VimEnter * PlugInstall --sync | source $MYVIMRC
endif

"" Start Vim-Plug
call plug#begin('~/.vim/plugged')

"" Cond loading
function! Cond(cond, ...)
  let opts = get(a:000, 0, {})
  return a:cond ? opts : extend(opts, { 'on': [],'for': [] })
endfunction

" Themes
Plug 'kamwitsta/flatwhite-vim'
Plug 'tomasr/molokai'

" Extensions
Plug 'Shougo/deoplete.nvim'            , Cond(g:has_async,  { 'on': [] })
Plug 'Shougo/neco-vim'                 , {'for' : 'vim'}
Plug 'Shougo/neocomplete.vim'          , Cond(!g:has_async, { 'on': [] })
Plug 'Shougo/vimproc.vim'              , {'do' : 'make'}
Plug 'SirVer/ultisnips'                , { 'on': [] }
Plug 'Yggdroot/indentLine'
Plug 'airblade/vim-gitgutter'
Plug 'bronson/vim-trailing-whitespace'
Plug 'danchoi/ri.vim'                  , {'for' : 'ruby'}
Plug 'fatih/vim-go'                    , {'for' : 'go'}
Plug 'godlygeek/tabular'
Plug 'haya14busa/incsearch.vim'
Plug 'honza/vim-snippets'
Plug 'janko-m/vim-test'
Plug 'jiangmiao/auto-pairs'
Plug 'jpalardy/vim-slime'
Plug 'kien/ctrlp.vim'
Plug 'kien/rainbow_parentheses.vim'
Plug 'majutsushi/tagbar'
Plug 'osyo-manga/vim-over'
Plug 'qpkorr/vim-bufkill'              , {'on': 'BD'}
Plug 'racer-rust/vim-racer'            , {'for' : 'rust'}
Plug 'rizzatti/dash.vim'
Plug 'roxma/nvim-yarp'                 , Cond(g:has_async)
Plug 'roxma/vim-hug-neovim-rpc'        , Cond(g:has_async)
Plug 'rust-lang/rust.vim'              , {'for' : 'rust'}
Plug 'scrooloose/nerdcommenter'
Plug 'scrooloose/nerdtree'             , { 'on': 'NERDTreeToggle' }
Plug 'scrooloose/syntastic'            , Cond(!g:has_async)
Plug 'tpope/vim-bundler'               , {'for' : 'ruby' }
Plug 'tpope/vim-eunuch'
Plug 'tpope/vim-markdown'              , {'for' : 'markdown'}
Plug 'tpope/vim-projectionist'
Plug 'tpope/vim-rails'                 , {'for' : 'ruby' }
Plug 'tpope/vim-rake'                  , {'for' : 'ruby'}
Plug 'vim-airline/vim-airline'
Plug 'vim-airline/vim-airline-themes'
Plug 'vim-ruby/vim-ruby'               , {'for' : 'ruby' }
Plug 'w0rp/ale'                        , Cond(g:has_async)
Plug 'wincent/terminus'

for fpath in split(globpath('~/.vim/plug.d/', '*.vim'), '\n')
  exe 'source' fpath
endfor

" CTRL-P
  let g:ctrlp_cmd = 'CtrlPMixed'
  let g:ctrlp_working_path_mode = 'ra'
  if executable('ag')
    let g:ctrlp_user_command = 'ag -Q -l --nocolor --hidden -g "" %s'
  endif

" VIM-AIRPLAINE
  let g:airline_powerline_fonts = 1
  if !exists('g:airline_symbols')
    let g:airline_symbols = {}
  endif
  let g:airline_left_sep = '⮀'
  let g:airline_right_sep = '⮂'
  let g:airline_right_alt_sep = '⮃'
  let g:airline_left_alt_sep = '⮁'
  let g:airline_symbols.branch = '⭠'
  let g:airline_symbols.linenr= '⭡'
  let g:airline_symbols.readonly= '⭤'
  let g:airline#extensions#tabline#enabled = 1
  let g:airline#extensions#tabline#left_sep = ' '
  let g:airline#extensions#tabline#left_alt_sep = '|'
  let g:airline_theme = 'powerlineish'
  set laststatus=2
  set ttimeoutlen=50

" RAINBOW_PARENTHESE
  let g:rbpt_colorpairs = [
      \ ['brown',       'RoyalBlue3'],
      \ ['Darkblue',    'SeaGreen3'],
      \ ['darkgray',    'DarkOrchid3'],
      \ ['darkgreen',   'firebrick3'],
      \ ['darkcyan',    'RoyalBlue3'],
      \ ['darkred',     'SeaGreen3'],
      \ ['darkmagenta', 'DarkOrchid3'],
      \ ['brown',       'firebrick3'],
      \ ['gray',        'RoyalBlue3'],
      \ ['black',       'SeaGreen3'],
      \ ['darkmagenta', 'DarkOrchid3'],
      \ ['Darkblue',    'firebrick3'],
      \ ['darkgreen',   'RoyalBlue3'],
      \ ['darkcyan',    'SeaGreen3'],
      \ ['darkred',     'DarkOrchid3'],
      \ ['red',         'firebrick3'],
      \ ]
  let g:rbpt_max = 16
  au VimEnter * RainbowParenthesesToggle
  au Syntax * RainbowParenthesesLoadRound
  au Syntax * RainbowParenthesesLoadSquare
  au Syntax * RainbowParenthesesLoadBraces



call plug#end()
